:mod:`animanager.xml` --- XML tools
=======================================

.. automodule:: animanager.xml

.. autoclass:: XMLTree

   .. automethod:: parse
   .. automethod:: fromstring

   .. automethod:: write
